summaryrefslogtreecommitdiffstats
path: root/kmail/vacation.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/vacation.cpp')
-rw-r--r--kmail/vacation.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/kmail/vacation.cpp b/kmail/vacation.cpp
index d3440a97..cee3a3cb 100644
--- a/kmail/vacation.cpp
+++ b/kmail/vacation.cpp
@@ -212,7 +212,7 @@ namespace {
static const GenericInformationExtractor::StateNode spamNodes[] = {
{ 0, GIE::CommandStart, "if", 1, 0, 0 }, // 0
{ 0, GIE::TestStart, "header", 2, 0, 0 }, // 1
- { 0, GIE::TaggedArgument, "tqcontains", 3, 0, 0 }, // 2
+ { 0, GIE::TaggedArgument, "contains", 3, 0, 0 }, // 2
// accept both string and string-list:
{ 0, GIE::StringArgument, "x-spam-flag", 9, 4, "x-spam-flag" }, // 3
@@ -232,7 +232,7 @@ namespace {
{ 0, GIE::TestEnd, 0, 16, 0, 0 }, // 15
- // block of command, tqfind "stop", take nested if's into account:
+ // block of command, find "stop", take nested if's into account:
{ 0, GIE::BlockStart, 0, 17, 0, 0 }, // 16
{ 1, GIE::CommandStart, "stop", 20, 19, "stop" }, // 17
{ -1, GIE::Any, 0, 17, 0, 0 }, // 18
@@ -259,7 +259,7 @@ namespace {
// to understand this table, study the output of
// libksieve/tests/parsertest
// 'if not address :domain :tqcontains ["from"] ["mydomain.org"] { keep; stop; }'
static const GenericInformationExtractor::StateNode domainNodes[] = {
{ 0, GIE::CommandStart, "if", 1, 0, 0 }, // 0
{ 0, GIE::TestStart, "not", 2, 0, 0, }, // 1
@@ -267,8 +267,8 @@ namespace {
// :domain and :contains in arbitrary order:
{ 0, GIE::TaggedArgument, "domain", 4, 5, 0 }, // 3
- { 0, GIE::TaggedArgument, "tqcontains", 7, 0, 0 }, // 4
- { 0, GIE::TaggedArgument, "tqcontains", 6, 0, 0 }, // 5
+ { 0, GIE::TaggedArgument, "contains", 7, 0, 0 }, // 4
+ { 0, GIE::TaggedArgument, "contains", 6, 0, 0 }, // 5
{ 0, GIE::TaggedArgument, "domain", 7, 0, 0 }, // 6
// accept both string and string-list:
@@ -288,7 +288,7 @@ namespace {
{ 0, GIE::TestEnd, 0, 18, 0, 0 }, // 17
{ 0, GIE::TestEnd, 0, 19, 0, 0 }, // 18
- // block of commands, tqfind "stop", take nested if's into account:
+ // block of commands, find "stop", take nested if's into account:
{ 0, GIE::BlockStart, 0, 20, 0, 0 }, // 19
{ 1, GIE::CommandStart, "stop", 23, 22, "stop" }, // 20
{ -1, GIE::Any, 0, 20, 0, 0 }, // 21
@@ -448,9 +448,9 @@ namespace KMail {
static inline TQString dotstuff( TQString s ) {
if ( s.startsWith( "." ) )
- return '.' + s.tqreplace( "\n.", "\n.." );
+ return '.' + s.replace( "\n.", "\n.." );
else
- return s.tqreplace( "\n.", "\n.." );
+ return s.replace( "\n.", "\n.." );
}
TQString Vacation::composeScript( const TQString & messageText,
@@ -464,18 +464,18 @@ namespace KMail {
addressesArgument += ":addresses [ ";
TQStringList sl;
for ( AddrSpecList::const_iterator it = addrSpecs.begin() ; it != addrSpecs.end() ; ++it ) {
- sl.push_back( '"' + (*it).asString().tqreplace( '\\', "\\\\" ).tqreplace( '"', "\\\"" ) + '"' );
+ sl.push_back( '"' + (*it).asString().replace( '\\', "\\\\" ).replace( '"', "\\\"" ) + '"' );
aliases.push_back( (*it).asString() );
}
addressesArgument += sl.join( ", " ) + " ] ";
}
TQString script = TQString::tqfromLatin1("require \"vacation\";\n\n" );
if ( !sendForSpam )
- script += TQString::tqfromLatin1( "if header :tqcontains \"X-Spam-Flag\" \"YES\""
+ script += TQString::tqfromLatin1( "if header :contains \"X-Spam-Flag\" \"YES\""
" { keep; stop; }\n" ); // FIXME?
if ( !domain.isEmpty() ) // FIXME
- script += TQString::tqfromLatin1( "if not address :domain :tqcontains \"from\" \"%1\" { keep; stop; }\n" ).tqarg( domain );
+ script += TQString::tqfromLatin1( "if not address :domain :contains \"from\" \"%1\" { keep; stop; }\n" ).tqarg( domain );
script += "vacation ";
script += addressesArgument;
@@ -608,7 +608,7 @@ namespace KMail {
mSieveJob = 0; // job deletes itself after returning from this slot!
if ( !mCheckOnly && mUrl.protocol() == "sieve" && !job->sieveCapabilities().isEmpty() &&
- !job->sieveCapabilities().tqcontains("vacation") ) {
+ !job->sieveCapabilities().contains("vacation") ) {
KMessageBox::sorry( 0, i18n("Your server did not list \"vacation\" in "
"its list of supported Sieve extensions;\n"
"without it, KMail cannot install out-of-"
@@ -259,7 +259,7 @@ namespace {
// to understand this table, study the output of
// libksieve/tests/parsertest
- // 'if not address :domain :tqcontains ["from"] ["mydomain.org"] { keep; stop; }'
+ // 'if not address :domain :contains ["from"] ["mydomain.org"] { keep; stop; }'
static const GenericInformationExtractor::StateNode domainNodes[] = {
{ 0, GIE::CommandStart, "if", 1, 0, 0 }, // 0